==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/choicecase/rev20160624/choicecase/snack/DefaultSportsarena.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.choicecase.rev20160624.choicecase.snack;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.choicecase.rev20160624.choicecase.Snack;
import org.onosproject.yang.gen.v1.choicecase.rev20160624.choicecase.snack.sportsarena.Bear;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of sportsarena.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultSportsarena extends InnerModelObject implements Sportsarena {
    protected boolean pretzel;
    protected BitSet valueLeafFlags = new BitSet();
    protected Bear bear;

    @Override
    public boolean pretzel() {
        return pretzel;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public Bear bear() {
        return bear;
    }

    @Override
    public void pretzel(boolean pretzel) {
        valueLeafFlags.set(LeafIdentifier.PRETZEL.getLeafIndex());
        this.pretzel = pretzel;
    }

    @Override
    public void bear(Bear bear) {
        this.bear = bear;
    }

    @Override
    public int hashCode() {
        return Objects.hash(pretzel, valueLeafFlags, bear);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultSportsarena) {
            DefaultSportsarena other = (DefaultSportsarena) obj;
            return
                Objects.equals(pretzel, other.pretzel) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.equals(bear, other.bear);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("pretzel=" + pretzel)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("bear=" + bear)
            .toString();
    }


    /**
     * Creates an instance of defaultSportsarena.
     */
    public DefaultSportsarena() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/choicecase/rev20160624/choicecase/snack/DefaultSportsarena.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.choicecase.rev20160624.choicecase.snack;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.choicecase.rev20160624.choicecase.Snack;
import org.onosproject.yang.gen.v1.choicecase.rev20160624.choicecase.snack.sportsarena.Bear;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of sportsarena.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultSportsarena extends InnerModelObject implements Sportsarena {
    protected boolean pretzel;
    protected BitSet valueLeafFlags = new BitSet();
    protected Bear bear;

    @Override
    public boolean pretzel() {
        return pretzel;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public Bear bear() {
        return bear;
    }

    @Override
    public void pretzel(boolean pretzel) {
        valueLeafFlags.set(LeafIdentifier.PRETZEL.getLeafIndex());
        this.pretzel = pretzel;
    }

    @Override
    public void bear(Bear bear) {
        this.bear = bear;
    }

    @Override
    public int hashCode() {
        return Objects.hash(pretzel, valueLeafFlags, bear);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultSportsarena) {
            DefaultSportsarena other = (DefaultSportsarena) obj;
            return
                Objects.deepEquals(pretzel, other.pretzel) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.deepEquals(bear, other.bear);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("pretzel=" + pretzel)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("bear=" + bear)
            .toString();
    }


    /**
     * Creates an instance of defaultSportsarena.
     */
    public DefaultSportsarena() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
